@@ -22,6 +22,8 @@ type Addon struct {
 	// ARN of the permissions boundary to associate
 	// +optional
 	PermissionsBoundary string `json:"permissionsBoundary,omitempty"`
+	// WellKnownPolicies for attaching common IAM policies
+	WellKnownPolicies WellKnownPolicies `json:"wellKnownPolicies,omitempty"`
 	// The metadata to apply to the cluster to assist with categorization and organization.
 	// Each tag consists of a key and an optional value, both of which you define.
 	// +optional
@@ -60,8 +62,12 @@ func (a Addon) checkOnlyOnePolicyProviderIsSet() error {
 		setPolicyProviders++
 	}
 
+	if a.WellKnownPolicies.HasPolicy() {
+		setPolicyProviders++
+	}
+
 	if setPolicyProviders > 1 {
-		return fmt.Errorf("at most one of serviceAccountRoleARN, attachPolicyARNs and attachPolicy can be specified")
+		return fmt.Errorf("at most one of wellKnownPolicies, serviceAccountRoleARN, attachPolicyARNs and attachPolicy can be specified")
 	}
 	return nil
 }
