@@ -34,8 +34,6 @@ import (
 // Values for `KubernetesVersion`
 // All valid values should go in this block
 const (
-	Version1_17 = "1.17"
-
 	Version1_18 = "1.18"
 
 	Version1_19 = "1.19"
@@ -71,6 +69,9 @@ const (
 
 	// Version1_16 represents Kubernetes version 1.16.x
 	Version1_16 = "1.16"
+
+	// Version1_17 represents Kubernetes version 1.17.x
+	Version1_17 = "1.17"
 )
 
 // Not yet supported versions
@@ -415,6 +416,7 @@ func DeprecatedVersions() []string {
 		Version1_14,
 		Version1_15,
 		Version1_16,
+		Version1_17,
 	}
 }
 
@@ -431,7 +433,6 @@ func IsDeprecatedVersion(version string) bool {
 // SupportedVersions are the versions of Kubernetes that EKS supports
 func SupportedVersions() []string {
 	return []string{
-		Version1_17,
 		Version1_18,
 		Version1_19,
 		Version1_20,
@@ -1116,6 +1117,10 @@ type (
 	}
 	// NodeGroupIAM holds all IAM attributes of a NodeGroup
 	NodeGroupIAM struct {
+		// AttachPolicy holds a policy document to attach
+		// +optional
+		AttachPolicy InlineDocument `json:"attachPolicy,omitempty"`
+		// list of ARNs of the IAM policies to attach
 		// +optional
 		AttachPolicyARNs []string `json:"attachPolicyARNs,omitempty"`
 		// +optional
